==> haskell-monad-logger-0.3.36-113-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-monad-logger.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 monad-logger
version:              0.3.36
visibility:           public
id:                   monad-logger-0.3.36-88HtEpHUOt28VRBr4QzClQ
key:                  monad-logger-0.3.36-88HtEpHUOt28VRBr4QzClQ
license:              MIT
maintainer:           michael@snoyman.com
author:               Michael Snoyman
homepage:             https://github.com/snoyberg/monad-logger#readme
synopsis:             A class of monads which can log messages.
description:
    See README and Haddocks at <https://www.stackage.org/package/monad-logger>

category:             System
abi:                  dce826281d01536b841e4220a1cfbfb2
exposed:              True
exposed-modules:      Control.Monad.Logger Control.Monad.Logger.CallStack
hidden-modules:       Paths_monad_logger
import-dirs:          /usr/lib/ghc-9.0.1/site-local/monad-logger-0.3.36
library-dirs:         /usr/lib/ghc-9.0.1/site-local/monad-logger-0.3.36
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-9.0.1/monad-logger-0.3.36
hs-libraries:         HSmonad-logger-0.3.36-88HtEpHUOt28VRBr4QzClQ
depends:
    base-4.15.0.0 bytestring-0.10.12.1
    conduit-1.3.4.1-7ubKvw2j8afFY9XAmrTviB
    conduit-extra-1.3.5-CQXMMDSa9L4A4JxSApSKqi exceptions-0.10.4
    fast-logger-3.0.5-IysYcV2jXsAF8pKqshkQrT
    lifted-base-0.2.3.12-FGUj9Dlhl4OBJnweRSmOlB
    monad-control-1.0.3.1-BNgENcrTprEBkmgJW18eed
    monad-loops-0.4.3-CoSqVlGqFyAAyK5Lg2m9AJ mtl-2.2.2
    resourcet-1.2.4.3-5mw5zFcSXi7BloHs1uJB6P stm-2.5.0.0
    stm-chans-3.0.0.4-JaCKTIrTqQsE12KvNGyu2w template-haskell-2.17.0.0
    text-1.2.4.1 transformers-0.5.6.2
    transformers-base-0.4.6-DdORi76Q0sMCnvGVm9cGnq
    transformers-compat-0.7-G46eeHH0vduAN6T7RnrFpu
    unliftio-core-0.2.0.1-2baD1vXgUkB5a1NRn2rSLN

haddock-interfaces:
    /usr/share/doc/haskell-monad-logger/html/monad-logger.haddock

haddock-html:         /usr/share/doc/haskell-monad-logger/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-monad-logger-0.3.36-119-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-monad-logger.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 monad-logger
version:              0.3.36
visibility:           public
id:                   monad-logger-0.3.36-9CK6KQsoQ7i19skL6vZYkj
key:                  monad-logger-0.3.36-9CK6KQsoQ7i19skL6vZYkj
license:              MIT
maintainer:           michael@snoyman.com
author:               Michael Snoyman
homepage:             https://github.com/snoyberg/monad-logger#readme
synopsis:             A class of monads which can log messages.
description:
    See README and Haddocks at <https://www.stackage.org/package/monad-logger>

category:             System
abi:                  6f9d53d5638e3a76f811d814dd7d7d66
exposed:              True
exposed-modules:      Control.Monad.Logger Control.Monad.Logger.CallStack
hidden-modules:       Paths_monad_logger
import-dirs:          /usr/lib/ghc-9.0.1/site-local/monad-logger-0.3.36
library-dirs:         /usr/lib/ghc-9.0.1/site-local/monad-logger-0.3.36
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-9.0.1/monad-logger-0.3.36
hs-libraries:         HSmonad-logger-0.3.36-9CK6KQsoQ7i19skL6vZYkj
depends:
    base-4.15.0.0 bytestring-0.10.12.1
    conduit-1.3.4.1-APoT7S8i9fNAuDbLjFbyiG
    conduit-extra-1.3.5-Jb775pqQofeLr1tpdbSUmT exceptions-0.10.4
    fast-logger-3.0.5-8WE077AyZaB4w4u1167Moe
    lifted-base-0.2.3.12-GbBxJZdldOe18CReEPyAMR
    monad-control-1.0.3.1-FVuy6K1bG22AmzeecOYTsL
    monad-loops-0.4.3-CoSqVlGqFyAAyK5Lg2m9AJ mtl-2.2.2
    resourcet-1.2.4.3-53FYjKR289QGvVsOPGH1yC stm-2.5.0.0
    stm-chans-3.0.0.4-JaCKTIrTqQsE12KvNGyu2w template-haskell-2.17.0.0
    text-1.2.4.1 transformers-0.5.6.2
    transformers-base-0.4.6-AfHPvxbHl4uCAVG5DYtFvV
    transformers-compat-0.7-G46eeHH0vduAN6T7RnrFpu
    unliftio-core-0.2.0.1-2baD1vXgUkB5a1NRn2rSLN

haddock-interfaces:
    /usr/share/doc/haskell-monad-logger/html/monad-logger.haddock

haddock-html:         /usr/share/doc/haskell-monad-logger/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
